# pyRealEstate

pyRealEstate is a package designed for data scientists working in the real estate industry.  This Library aims to provide tools to help in the preprocessing of data, feature engineering and evaluation 
of AVM's (Automated Valuation Models). Some of the metrics provided in this library are the COD ( Coeficient of Disspersion), PRD ( Price Related Differential) and weighted mean for example. pyRealEstate is still currently under development, please check back for updates frequently. 

## Installation

Simply run:
```
pip install pyRealEstate
```
